summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorPrasad Bg Ranganath <prasadbgr@in.ibm.com>2016-10-03 00:02:45 -0500
committerSachin Gupta <sgupta2m@in.ibm.com>2016-10-04 07:23:38 -0400
commit4777ee2974f304c42de6b1a3d4b0107ca60af9ad (patch)
tree460b042ceb342cb6d5c1b73e586cbf19b63d9577
parent9e89ef08ab80466c0eb3873540863f9046c321e1 (diff)
downloadtalos-sbe-4777ee2974f304c42de6b1a3d4b0107ca60af9ad.tar.gz
talos-sbe-4777ee2974f304c42de6b1a3d4b0107ca60af9ad.zip
SBE:putring:Increase the poll count
Change-Id: I5f38ae68449ec449e80a4edbb75f0fbe7a1a5535 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/30597 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: PPE CI <ppe-ci+hostboot@us.ibm.com> Reviewed-by: Gregory S. Still <stillgs@us.ibm.com> Reviewed-by: PARVATHI RACHAKONDA <prachako@in.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/30600 Reviewed-by: Hostboot Team <hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Sachin Gupta <sgupta2m@in.ibm.com>
-rw-r--r--src/import/chips/p9/utils/p9_putRingUtils.C4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/import/chips/p9/utils/p9_putRingUtils.C b/src/import/chips/p9/utils/p9_putRingUtils.C
index 15c4da60..ce968190 100644
--- a/src/import/chips/p9/utils/p9_putRingUtils.C
+++ b/src/import/chips/p9/utils/p9_putRingUtils.C
@@ -288,8 +288,8 @@ fapi2::ReturnCode standardScan(
// Add the chiplet ID in the Scom Address
l_OPCGAddress |= l_chiplet;
- // @TODO: Value 300 is a random number to start with.
- uint32_t l_attempts = 300;
+ // @TODO: Value 1000 is a random number to start with.
+ uint32_t l_attempts = 1000;
while(l_attempts > 0)
{
OpenPOWER on IntegriCloud